[cig-commits] r6693 - mc/3D/CitcomS/branches/compressible/CitcomS/Solver

tan2 at geodynamics.org tan2 at geodynamics.org
Wed Apr 25 17:46:11 PDT 2007


Author: tan2
Date: 2007-04-25 17:46:11 -0700 (Wed, 25 Apr 2007)
New Revision: 6693

Modified:
   mc/3D/CitcomS/branches/compressible/CitcomS/Solver/CoupledSolver.py
Log:
Updating CoupledSolver for the checkpoint and tracers. The checkpoint stuff is not finished.

Modified: mc/3D/CitcomS/branches/compressible/CitcomS/Solver/CoupledSolver.py
===================================================================
--- mc/3D/CitcomS/branches/compressible/CitcomS/Solver/CoupledSolver.py	2007-04-26 00:45:51 UTC (rev 6692)
+++ mc/3D/CitcomS/branches/compressible/CitcomS/Solver/CoupledSolver.py	2007-04-26 00:46:11 UTC (rev 6693)
@@ -62,8 +62,11 @@
 
     def launch(self, application):
         print self.name, 'enter launch'
-        self._setup()
 
+        #TODO: checkpoint doesn't contain coupler information yet
+        if self.restart:
+            pass
+
         self.coupler.launch(self)
 
         ic = self.inventory.ic
@@ -89,8 +92,8 @@
 
 
 
-    def solveAdditional(self):
-        # override Solver.solveAdditional, since tracer module
+    def advectTracers(self):
+        # override Solver.advectTracers, since tracer module
         # doesn't work in coupled run
         return
 
@@ -140,9 +143,16 @@
         return
 
 
+    def checkpoint(self, checkpointFrequency):
+        Solver.checkpoint(self, checkpointFrequency)
 
+        if not (self.step % checkpointFrequency):
+            #TODO: checkpoint for coupler
+            pass
+        return
 
 
+
 # version
 __id__ = "$Id$"
 



More information about the cig-commits mailing list